# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceTypeRequest(Model):
    """PlaceTypeRequest.

    :param place_type_info: The place type info <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type place_type_info: str
    """

    _validation = {
        'place_type_info': {'required': True, 'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'place_type_info': {'key': 'placeTypeInfo', 'type': 'str'},
    }

    def __init__(self, place_type_info):
        super(PlaceTypeRequest, self).__init__()
        self.place_type_info = place_type_info
